@@ -59,9 +59,9 @@ pref("general.warnOnAboutConfig", true);
 pref("browser.bookmarks.max_backups",       5);
 
 pref("browser.cache.disk.enable",           true);
-//@line 63 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 63 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         51200);
-//@line 67 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 67 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 pref("browser.cache.memory.enable",         true);
 //pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
@@ -70,7 +70,7 @@ pref("browser.cache.disk_cache_ssl",        false);
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 76 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 76 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -81,7 +81,7 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 92 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 92 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
@@ -145,11 +145,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 156 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 156 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 159 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 159 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 161 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 161 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -162,16 +162,16 @@ pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 176 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 176 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
-//@line 178 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 178 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 185 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 185 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -184,7 +184,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 201 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 201 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -528,9 +528,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 545 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 545 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 547 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 547 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -579,7 +579,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 598 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 598 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -734,6 +734,7 @@ pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
 pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.ua", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
@@ -742,6 +743,8 @@ pref("network.IDN.whitelist.xn--mgbaam7a8h", true);
 // cn, China, .<China> with variants
 pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
 pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// eg, Egypt, .<Masr>
+pref("network.IDN.whitelist.xn--wgbh1c", true);
 // hk, Hong Kong, .<Hong Kong>
 pref("network.IDN.whitelist.xn--j6w193g", true);
 // ir, Iran, <.Iran> with variants
@@ -848,7 +851,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 872 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 875 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1269,15 +1272,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1690 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 1693 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
-//@line 2114 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2117 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
-//@line 2317 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2320 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
-//@line 2413 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2416 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
-//@line 2416 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2419 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1547,15 +1550,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2688 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2691 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
-//@line 2756 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2759 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
-//@line 2782 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2785 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
-//@line 2802 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2805 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
-//@line 2810 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2813 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1592,9 +1595,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2852 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2855 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
-//@line 2857 "/builds/moz2_slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
+//@line 2860 "/builds/slave/192-lnx-dbg/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
